import pygame, sys
from lib.karakter import Karakter

BLANK = pygame.image.load('data/images/blank.png')
WALL  = pygame.image.load('data/images/wall.png')
TILESIZE = 32
TILESX = 32
TILESY = 22

def getTileCoords(x, y):
    px = TILESIZE * x
    py = TILESIZE * y
    return px, py





class Map():
    def __init__(self):
        self.levels = self.loadMap('levels.txt')
        self.wallsRects = []

    def loadMap(self, filepath):
        f = open(filepath)

        levels = range(10)
        for i in levels:
            levels[i] = ''

        i =0
        for line in f.readlines():
            if line =='\n':
                i += 1
                continue
            levels[i] += line
        return levels

    def drawMap(self, screen,  levelIndex):
        x, y = 0, 0
        for tile in self.levels[levelIndex]:
            if tile == ' ':
                screen.blit(BLANK, getTileCoords(x, y))
            elif tile == '#':
                nx, ny = getTileCoords(x, y)
                screen.blit(WALL, (nx, ny))
                rect = WALL.get_rect()
                rect.top, rect.left = nx, ny
                self.wallsRects.append(rect)
            
            if x < TILESX:
                x += 1
            else:
                y += 1
                x = 0

    # xxp = x player pos, ypp = y player pos        
    def collideWall(self, playerRect ):
        
        for wall in self.wallsRects:
            if playerRect.colliderect(wall):
                return True






        

def main():
    """ your app starts here
    """

    pygame.init()

    screen = pygame.display.set_mode((1024, 704))
    pygame.display.set_caption("Moon Wheel")
    clock = pygame.time.Clock()

    mainMap = Map()
    s = {'d': Karakter(getTileCoords(3,5))}
    zombie = s['d']
    while True:
        
        for event in pygame.event.get():
            if event.type == pygame.QUIT:
                sys.exit()
            elif event.type == pygame.KEYDOWN:
                if event.key == pygame.K_ESCAPE:
                    pygame.quit()
                    sys.exit()
                

                

        mainMap.drawMap(screen, 1)

        zombie.update(screen)
        if mainMap.collideWall(zombie.getRect()):
            pass


        pygame.display.flip()
        clock.tick(30)



if __name__ == '__main__':
    main()
