import pygame, sys, data, util
from Player import Player
from Zombies import *

class Coin(pygame.sprite.Sprite):
    def __init__(self, rect):
        pygame.sprite.Sprite.__init__(self)
        self.frames   = util.cutKarakter('coin.png', 1, 4)
        self.colleted = False
        self.currentFrame = 0
        self.rect = rect

    def update(self, screen):

        screen.blit(self.frames[0][self.currentFrame], (self.rect.top, self.rect.left))
        if self.currentFrame < 3:
            self.currentFrame += 1
        else:
            self.currentFrame = 0


        
class Map():
    def __init__(self, levelIndex, game):
        
       self.tiles = {'#': util.loadImage(data.imagepath('wall.png')),
                    '.': util.loadImage(data.imagepath('blank.png'))
       }

       self.levels = self.loadMap(data.filepath('levels.txt'))
       self.levelIndex = levelIndex
       self.wallRects = []
       self.visiblesSprites = []
       self.player = None
       self.initialPos = {'1' : [], '2': [], '3': [], '4': [], '5': [], '6': [], '7': [], '8': []}
       self.zombies = []

       self.coinsRects = []
       self.coins = []
       self.lifesRects = []
       self.lifes = []
       self.lifeImage = util.loadImage(data.imagepath('life.png'), True, True)
       

       self.game = game

       self.ticks = 0
       self.portals = []

       self.spaceShip = pygame.image.load(data.imagepath('ship.png'))


    def loadMap(self, filepath):
            f = open(filepath)

            levels = range(10)
            for i in levels:
                levels[i] = ''

            i = 0
            for line in f.readlines():
                if line == '\n' :
                    i += 1
                    continue
                levels[i] += line

            return levels

    def drawMap(self, screen, levelIndex):
        # grid x and y
        gx, gy = 0, 1
        for tile  in self.levels[levelIndex]:
            if tile == ' ':
                screen.blit(self.tiles['.'], util.getTileCoords(gx, gy))
            elif tile == '#':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['#'], (x,y))

                rect = self.tiles['#'].get_rect()
                rect.top, rect.left = x, y
                self.wallRects.append(rect)

            elif tile == '@':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                self.initialPos['@'] = x,y

            elif tile == '1':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                self.initialPos['1'].append(( x,y))

            elif tile == '2':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                self.initialPos['2'].append(( x,y))

            elif tile == '3':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                self.initialPos['3'].append(( x,y))

            elif tile == '4':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                self.initialPos['4'].append(( x,y))

            elif tile == '5':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                self.initialPos['5'].append(( x,y))

            elif tile == '6':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                self.initialPos['6'].append(( x,y))

            elif tile == '7':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                self.initialPos['7'].append(( x,y))

            elif tile == '8':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                self.initialPos['8'].append(( x,y))

            elif tile == '0':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                rect = pygame.Rect(x, y, 32, 32)
                rect.top, rect.left = x + 10, y + 10
                self.coinsRects.append(rect)

            elif tile == 'l':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                rect = pygame.Rect(x, y, 32, 32)
                rect.top, rect.left = x,y
                self.lifesRects.append(rect)

            elif tile == '$':
                x, y = util.getTileCoords(gx, gy)
                screen.blit(self.tiles['.'], (x,y))
                screen.blit(self.spaceShip, (x,y))
                self.shipRect = self.spaceShip.get_rect()
                self.shipRect.top, self.shipRect.left = x, y

            elif tile == '+':
                screen.blit(self.tiles['.'], util.getTileCoords(gx, gy))
                screen.blit(self.spaceShip, (self.shipRect.top, self.shipRect.left))

            else:
                x, y = util.getTileCoords(gx, gy)
                pos = x, y
                screen.blit(self.tiles['.'], (x,y))
                rect = pygame.Rect(x, y, 32, 32)
                rect.top, rect.left = x, y
                self.portals.append((tile, rect))




            if gx < util.TILESX:
                gx += 1
            else:
                gy += 1
                gx = 0

    def initial(self, screen, playerEstate):
        self.drawMap(screen, self.levelIndex)
        self.player = playerEstate
        self.player.setPos(self.initialPos['@'])

        for i in self.initialPos['1']:
            self.zombies.append( Zombie1(i))
        for i in self.initialPos['2']:
            self.zombies.append( Zombie2(i))
        for i in self.initialPos['3']:
            self.zombies.append( Zombie3(i))
        for i in self.initialPos['4']:
            self.zombies.append( Zombie4(i))
        for i in self.initialPos['5']:
            self.zombies.append( Zombie5(i))
        for i in self.initialPos['6']:
            self.zombies.append( Zombie6(i))
        for i in self.initialPos['7']:
            self.zombies.append( Zombie7(i))
        for i in self.initialPos['8']:
            self.zombies.append( Zombie8(i))

        for rect in self.coinsRects:
            pos = (rect.top , rect.left)
            newCoin = Coin(rect)
            for  coin in self.player.coinsColleted:
                if pos == coin:
                    newCoin.colleted = True
            self.coins.append(newCoin)

        for rect in self.lifesRects:
            pos = (rect.top , rect.left)
            aux = False
            for life  in self.player.lifesColleted:
                if pos == life:
                    aux = True   

            if not aux:        
                self.lifes.append(rect)
                    



    def update(self, screen):
        
        self.drawMap(screen, self.levelIndex)
        self.player.update(screen, self)

        for zombie in self.zombies:

            if self.player.rect.colliderect(zombie.rect):
                self.player.die()
                self.transtition(screen)
                if self.player.lifes < 0:
                    self.game.estate = 'gameOver'
                else:
                    self.game.startGame(self.levelIndex, self.player)
            
            zombie.update(screen, self.wallRects, self.player.rect)

        for portal in self.portals:
            index, rect = portal
            if self.player.rect.colliderect(rect):
                self.transtition(screen)
                self.levelIndex = util.getLevelIndex(index)
                self.game.startGame(self.levelIndex, self.player)

        for coin  in self.coins:
            if not coin.colleted:
                if self.player.rect.colliderect(coin.rect):
                    coin.colleted = True
                    self.player.coins += 1
                    self.player.coinsColleted.append((coin.rect.top,coin.rect.left))
                coin.update(screen)
                if self.player.coins == 25:
                     self.player.lifes += 1
                     self.player.coins = 0

        for life in self.lifes:
            aux = False
            pos = life.top,life.left
            for lifec  in self.player.lifesColleted:
                if pos == lifec:
                    aux = True   

            if not aux: 
                if self.player.rect.colliderect(life):
                    self.player.lifes += 1
                    self.player.lifesColleted.append((life.top,life.left))
                screen.blit(self.lifeImage, (life.top,life.left))


        if self.levelIndex == 9:
            if self.player.rect.colliderect(self.shipRect):
                self.transtition(screen)
                self.game.estate = 'gameWon'





    def transtition(self, screen):
        screen.fill((0,0,0))
        pygame.display.update()



    