import pygame, data, util


class Player(pygame.sprite.Sprite):
    def __init__(self, (x ,y)):
        pygame.sprite.Sprite.__init__(self)

        self.sprite = util.cutKarakter('player.png', 4, 3)
        self.image  = self.sprite[0][1]

        self.rect  = self.image.get_rect()
        self.rect.inflate_ip(-10 , -10)

        self.lifes = 3
        self.coins = 0
        self.coinImage = util.cutKarakter('coin.png', 1, 4)[0][1]
        self.coinsColleted = []
        self.lifesColleted = []

        self.downFrames = [ self.sprite[0][0],
                            self.sprite[0][1],
                            self.sprite[0][2],
        ]
        self.leftFrames = [ self.sprite[1][0],
                            self.sprite[1][1],
                            self.sprite[1][2],
        ]
        self.rightFrames = [self.sprite[2][0],
                            self.sprite[2][1],
                            self.sprite[2][2],
        ]
        self.upFrames= [self.sprite[3][0],
                        self.sprite[3][1],
                        self.sprite[3][2],
        ]

        self.currentFrame = 0
        self.vx           = x
        self.vy           = y
        self.speed        = 15

        self.clock = pygame.time.Clock()

        self.moving   = False
        self.lefting  = False
        self.downing  = False
        self.righting = False
        self.uping    = False

    def getFrame(self, frames):
        if self.currentFrame < len(frames) - 1:
            self.currentFrame += 1
        else:
            self.currentFrame = 0

        return self.currentFrame

    def handleEvents(self):
        if pygame.key.get_pressed()[pygame.K_DOWN]:
            self.moving  = True
            self.downing = True
            self.vy += self.speed

        if pygame.key.get_pressed()[pygame.K_UP]:
            self.moving  = True
            self.uping = True
            self.vy -= self.speed

        if pygame.key.get_pressed()[pygame.K_LEFT]:
            self.moving  = True
            self.lefting = True
            self.vx -= self.speed

        if pygame.key.get_pressed()[pygame.K_RIGHT]:
            self.moving  = True            
            self.righting = True
            self.vx += self.speed

    def move(self):
        if self.lefting:
            currentFrame = self.getFrame(self.leftFrames)
            self.image = self.leftFrames[currentFrame]
        elif self.righting:
            currentFrame = self.getFrame(self.rightFrames)
            self.image = self.rightFrames[currentFrame]
        elif self.uping:
            currentFrame = self.getFrame(self.upFrames)
            self.image = self.upFrames[currentFrame]
        elif self.downing:
            currentFrame = self.getFrame(self.downFrames)
            self.image = self.downFrames[currentFrame]


    def hasWallCollition(self, mapInstance, playerRect):
        for wall in mapInstance.wallRects:
            if playerRect.colliderect(wall):
                return True

        return False

    def die(self):
        self.lifes -= 1

    def stopAction(self):
        self.moving   = False
        self.lefting  = False
        self.downing  = False
        self.righting = False
        self.uping    = False

    def update(self, screen, mapInstance):
        self.stopAction()
        oldPos = self.vx, self.vy

        self.handleEvents()

        newRect = self.rect
        newRect.top, newRect.left = self.vx, self.vy

        if self.moving and not self.hasWallCollition(mapInstance,newRect):
            self.move()
        else:
           self.vx, self.vy = oldPos

        screen.blit(self.image, (self.vx, self.vy))
        self.rect.top, self.rect.left = self.vx, self.vy
        
        if self.lifes >= 0:
            for i in range(self.lifes):
                lifeImage = pygame.image.load(data.imagepath('life.png'))
                screen.blit(lifeImage, util.getTileCoords(i,0))

        x,y = util.getTileCoords(29,0) 
        screen.blit(self.coinImage, (x+10,y+10))


        self.clock.tick(25)


    def getRect(self):
        return self.rect

    def getPos(self):
        return self.vx, self.vy 

    def setPos(self, (x,y)):
        self.vx, self.vy = x,y
        