import pygame, data, util, random


class Zombie(pygame.sprite.Sprite):
    def __init__(self, (x, y)):
        pygame.sprite.Sprite.__init__(self)

        self.sprite = util.cutKarakter('ZombieSheet.png', 8, 12)
       
        self.currentFrame = 0
        self.vx           = x
        self.vy           = y
        self.speed        = 15

        self.clock = pygame.time.Clock()

        self.moving   = False
        self.lefting  = False
        self.downing  = False
        self.righting = False
        self.uping    = False

        self.direction = random.choice(['l','r','u','d'])
        self.count = 0

    def getFrame(self, frames):
        if self.currentFrame < len(frames) - 1:
            self.currentFrame += 1
        else:
            self.currentFrame = 0

        return self.currentFrame

    def isIntersecting(self, sprite):
        if self != sprite and self.level == sprite.level and self.baseRect.colliderect(sprite.baseRect):
            return True
        return False;



    def move(self):
        if self.lefting:
            currentFrame = self.getFrame(self.leftFrames)
            self.image = self.leftFrames[currentFrame]
            self.vx -= self.speed
        elif self.righting:
            currentFrame = self.getFrame(self.rightFrames)
            self.image = self.rightFrames[currentFrame]
            self.vx += self.speed
        elif self.uping:
            currentFrame = self.getFrame(self.upFrames)
            self.image = self.upFrames[currentFrame]
            self.vy -= self.speed
        elif self.downing:
            currentFrame = self.getFrame(self.downFrames)
            self.image = self.downFrames[currentFrame]
            self.vy += self.speed

    def stopAction(self):
        self.moving   = False
        self.lefting  = False
        self.downing  = False
        self.righting = False
        self.uping    = False

    def hasWallCollition(self, walls, playerRect):
        for wall in walls:
            if playerRect.colliderect(wall):
                return True

        return False

    def update(self, screen, walls, playerRect):
        self.stopAction()
        oldPos = self.vx, self.vy

        self.count += 10
        if self.count == 100:
            self.changeDirection

        if not self.moving:
            self.ai()
            self.move()

        newRect = self.rect
        newRect.top, newRect.left = self.vx, self.vy

        if self.moving and not self.hasWallCollition(walls, newRect):
            if 0 < newRect.top < util.SCREENWIDTH and 0 < newRect.left < util.SCREENHEIGTH :
                self.move()            
            else:
                self.vx, self.vy = oldPos
                self.moving = False
                self.changeDirection()    
        else:
           self.vx, self.vy = oldPos
           self.moving = False
           self.changeDirection()

        screen.blit(self.image, (self.vx, self.vy))
        self.rect.top, self.rect.left = self.vx, self.vy

        self.clock.tick(25)

    def changeDirection(self):
        self.direction = random.choice(['l','r','u','d'])

    def ai(self):
        self.moving = True
        
        if self.direction == 'd':            
            self.downing = True
            

        if self.direction == 'u':            
            self.uping = True
            self.vy -= self.speed

        if self.direction == 'l':            
            self.lefting = True

        if self.direction == 'r':            
            self.righting = True







class Zombie1(Zombie):
    def __init__(self, (x,y)):
        super(Zombie1, self).__init__((x,y))

        self.image  = self.sprite[0][1]
        self.speed = 5

        self.rect  = self.image.get_rect()
        self.rect.inflate_ip(-5 , -10)
        self.rect.center = (50,50)

        self.downFrames = [ self.sprite[0][0],
                            self.sprite[0][1],
                            self.sprite[0][2],
        ]
        self.leftFrames = [ self.sprite[1][0],
                            self.sprite[1][1],
                            self.sprite[1][2],
        ]
        self.rightFrames = [self.sprite[2][0],
                            self.sprite[2][1],
                            self.sprite[2][2],
        ]
        self.upFrames= [self.sprite[3][0],
                        self.sprite[3][1],
                        self.sprite[3][2],
        ]

class Zombie2(Zombie):
    def __init__(self, (x,y)):
        super(Zombie2, self).__init__((x,y))

        self.image  = self.sprite[0][4]

        self.rect  = self.image.get_rect()
        self.rect.inflate_ip(-5 , -10)
        self.rect.center = (50,50)

        self.downFrames = [ self.sprite[0][3],
                            self.sprite[0][4],
                            self.sprite[0][5],
        ]
        self.leftFrames = [ self.sprite[1][3],
                            self.sprite[1][4],
                            self.sprite[1][5],
        ]
        self.rightFrames = [self.sprite[2][3],
                            self.sprite[2][4],
                            self.sprite[2][5],
        ]
        self.upFrames= [self.sprite[3][3],
                        self.sprite[3][4],
                        self.sprite[3][5],
        ]


class Zombie3(Zombie):
    def __init__(self, (x,y)):
        super(Zombie3, self).__init__((x,y))

        self.image  = self.sprite[0][7]

        self.rect  = self.image.get_rect()
        self.rect.inflate_ip(-5 , -10)
        self.rect.center = (50,50)

        self.downFrames = [ self.sprite[0][6],
                            self.sprite[0][7],
                            self.sprite[0][8],
        ]
        self.leftFrames = [ self.sprite[1][6],
                            self.sprite[1][7],
                            self.sprite[1][8],
        ]
        self.rightFrames = [self.sprite[2][6],
                            self.sprite[2][7],
                            self.sprite[2][8],
        ]
        self.upFrames= [self.sprite[3][6],
                        self.sprite[3][7],
                        self.sprite[3][8],
        ]

class Zombie4(Zombie):
    def __init__(self, (x,y)):
        super(Zombie4, self).__init__((x,y))

        self.image  = self.sprite[0][10]

        self.rect  = self.image.get_rect()
        self.rect.inflate_ip(-5 , -10)
        self.rect.center = (50,50)

        self.downFrames = [ self.sprite[0][9],
                            self.sprite[0][10],
                            self.sprite[0][11],
        ]
        self.leftFrames = [ self.sprite[1][9],
                            self.sprite[1][10],
                            self.sprite[1][11],
        ]
        self.rightFrames = [self.sprite[2][9],
                            self.sprite[2][10],
                            self.sprite[2][11],
        ]
        self.upFrames= [self.sprite[3][9],
                        self.sprite[3][10],
                        self.sprite[3][11],
        ]

class Zombie5(Zombie):
    def __init__(self, (x,y)):
        super(Zombie5, self).__init__((x,y))

        self.image  = self.sprite[4][0]

        self.rect  = self.image.get_rect()
        self.rect.inflate_ip(-5 , -10)
        self.rect.center = (50,50)

        self.downFrames = [ self.sprite[4][0],
                            self.sprite[4][1],
                            self.sprite[4][2],
        ]
        self.leftFrames = [ self.sprite[5][0],
                            self.sprite[5][1],
                            self.sprite[5][2],
        ]
        self.rightFrames = [self.sprite[6][0],
                            self.sprite[6][1],
                            self.sprite[6][2],
        ]
        self.upFrames= [self.sprite[7][0],
                        self.sprite[7][1],
                        self.sprite[7][2],
        ]

class Zombie6(Zombie):
    def __init__(self, (x,y)):
        super(Zombie6, self).__init__((x,y))

        self.image  = self.sprite[4][4]
        self.speed = 30

        self.rect  = self.image.get_rect()
        self.rect.inflate_ip(-5 , -10)
        self.rect.center = (50,50)

        self.downFrames = [ self.sprite[4][3],
                            self.sprite[4][4],
                            self.sprite[4][5],
        ]
        self.leftFrames = [ self.sprite[5][3],
                            self.sprite[5][4],
                            self.sprite[5][5],
        ]
        self.rightFrames = [self.sprite[6][3],
                            self.sprite[6][4],
                            self.sprite[6][5],
        ]
        self.upFrames= [self.sprite[7][3],
                        self.sprite[7][4],
                        self.sprite[7][5],
        ]
    

class Zombie7(Zombie):
    def __init__(self, (x,y)):
        super(Zombie7, self).__init__((x,y))

        self.image  = self.sprite[4][7]
        self.speed = 35

        self.rect  = self.image.get_rect()
        self.rect.inflate_ip(-5 , -10)
        self.rect.center = (50,50)

        self.downFrames = [ self.sprite[4][6],
                            self.sprite[4][7],
                            self.sprite[4][8],
        ]
        self.leftFrames = [ self.sprite[5][6],
                            self.sprite[5][7],
                            self.sprite[5][8],
        ]
        self.rightFrames = [self.sprite[6][6],
                            self.sprite[6][7],
                            self.sprite[6][8],
        ]
        self.upFrames= [self.sprite[7][6],
                        self.sprite[7][7],
                        self.sprite[7][8],
        ]

class Zombie8(Zombie):
    def __init__(self, (x,y)):
        super(Zombie8, self).__init__((x,y))

        self.image  = self.sprite[4][10]

        self.speed = 35

        self.rect  = self.image.get_rect()
        self.rect.inflate_ip(-5 , -10)
        self.rect.center = (50,50)

        self.downFrames = [ self.sprite[4][9],
                            self.sprite[4][10],
                            self.sprite[4][11],
        ]
        self.leftFrames = [ self.sprite[5][9],
                            self.sprite[5][10],
                            self.sprite[5][11],
        ]
        self.rightFrames = [self.sprite[6][9],
                            self.sprite[6][10],
                            self.sprite[6][11],
        ]
        self.upFrames= [self.sprite[7][9],
                        self.sprite[7][10],
                        self.sprite[7][11],
        ]


